@@ -1,6 +1,6 @@
 package Git::Hooks;
 # ABSTRACT: Framework for implementing Git (and Gerrit) hooks
-$Git::Hooks::VERSION = '1.13.1';
+$Git::Hooks::VERSION = '1.14.0';
 use 5.010;
 use strict;
 use warnings;
@@ -459,24 +459,29 @@ sub _gerrit_patchset_post_hook {
         $cfg{'votes-to-approve'} .= $cfg{'vote-ok'}  || '+1';
     }
 
-    my %params;
+    # https://gerrit-documentation.storage.googleapis.com/Documentation/2.13.1/rest-api-changes.html#set-review
+    my %review_input;
     my $auto_submit = 0;
 
     if (my @errors = $git->get_errors()) {
-        $params{labels}  = $cfg{'votes-to-reject'} || 'Code-Review-1';
-        $params{message} = join("\n\n", @errors);
+        $review_input{labels}  = $cfg{'votes-to-reject'} || 'Code-Review-1';
+        $review_input{message} = join("\n\n", @errors);
     } else {
-        $params{labels}  = $cfg{'votes-to-approve'} || 'Code-Review+1';
-        $params{message} = "[Git::Hooks] $cfg{'comment-ok'}"
+        $review_input{labels}  = $cfg{'votes-to-approve'} || 'Code-Review+1';
+        $review_input{message} = "[Git::Hooks] $cfg{'comment-ok'}"
             if $cfg{'comment-ok'};
         $auto_submit = 1 if $cfg{'auto-submit'};
     }
 
     # Convert, e.g., 'LabelA-1,LabelB+2' into { LabelA => '-1', LabelB => '+2' }
-    $params{labels} = { map {/^([-\w]+)([-+]\d+)$/i} split(',', $params{labels}) };
+    $review_input{labels} = { map {/^([-\w]+)([-+]\d+)$/i} split(',', $review_input{labels}) };
+
+    if (my $notify = $git->get_config('githooks.gerrit' => 'notify')) {
+        $review_input{notify} = $notify;
+    }
 
     # Cast review
-    eval { $args->{gerrit}->POST("/changes/$id/revisions/$patchset/review", \%params) }
+    eval { $args->{gerrit}->POST("/changes/$id/revisions/$patchset/review", \%review_input) }
         or die __PACKAGE__ . ": error in Gerrit::REST::POST(/changes/$id/revisions/$patchset/review): $@\n";
 
     # Auto submit if requested and passed verification
@@ -708,7 +713,7 @@ Git::Hooks - Framework for implementing Git (and Gerrit) hooks
 
 =head1 VERSION
 
-version 1.13.1
+version 1.14.0
 
 =head1 SYNOPSIS
 
@@ -1427,6 +1432,15 @@ This may be useful to provide a gentle introduction to Gerrit for people who
 don't want to start doing code reviews but want to use Gerrit simply as a
 Git server.
 
+=head2 githooks.gerrit.notify WHO
+
+Notify handling that defines to whom email notifications should be sent
+after the review is stored.
+
+Allowed values are NONE, OWNER, OWNER_REVIEWERS, and ALL.
+
+If not set, the default is ALL.
+
 =head2 githooks.gerrit.review-label LABEL
 
 This option is DEPRECATED. Please, use C<githooks.gerrit.votes-to-approve> and
